;; -----------------------------------------------------------------------------
;; Groups
;;
(defgroup cleite nil
  "Cleite :: Server-Based RSS Reader"
  :prefix "cleite:"
  :group 'rss)

(defgroup cleite:feeds nil
  "Cleite :: Feed List"
  :prefix "cleite:"
  :group 'cleite)

(defgroup cleite:items nil
  "Cleite :: Feed Item List"
  :prefix "cleite:"
  :group 'cleite)


;; -----------------------------------------------------------------------------
;; Variables [cleite]
;;
(defcustom cleite:daemon-host "localhost"
  "Hostname for the cleite daemon"
  :type 'string
  :group 'cleite)

(defcustom cleite:daemon-port 9895
  "Port for the cleite daemon"
  :type 'integer
  :group 'cleite)

(defcustom cleite:user-id "root"
  "Your user-id for the cleite daemon account"
  :type 'string
  :group 'cleite)

(defcustom cleite:measure-srpc-call-time nil
  "Measure how sRPC calls spend time and display it in the minibuffer."
  :type 'boolean
  :group 'cleite)


(defcustom cleite:auto-refresh-interval nil
  "Refresh feed list and feed items automatically for some minutes.

Note:

- The current implementation blocks the Emacs when it is
  interacting with the cleite daemon.  Enabling this option may
  annoy you suddenly.

- Reloading with too short interval may burden the cleite daemon.
  You should avoid that if you use a daemon which isn't owned by
  you."
  :type  '(choice (const  :tag "disabled" nil)
                  (number :tag "minutes"))
  :group 'cleite)


;; -----------------------------------------------------------------------------
;; Variables [cleite:feeds]
;;
(defcustom cleite:feeds:window-width 45
  "Width of the feed list window"
  :type  'integer
  :group 'cleite:feeds)


(defcustom cleite:feeds:sort-criteria '((read-flag . unread-first)
										(rank      . descending  )
										(title     . ascending   ))
  "Sort feeds by what criteria"
  :type  '(repeat (choice (const :tag "Feeds whose every items are read come first"
								 (read-flag . read-first))
						  (const :tag "Feeds that have at least one unread item come first"
								 (read-flag . unread-first))
						  (cons  (choice (const :tag "Sort by rank"  rank )
										 (const :tag "Sort by title" title)
										 (const :tag "Sort by date"  date ))
								 (choice (const :tag "Ascending"  ascending )
										 (const :tag "Descending" descending)))))
  :group 'cleite:feeds)


(defcustom cleite:feeds:display-feed-description nil
  "Display the description of each feeds in the minibuffer."
  :type  'boolean
  :group 'cleite:feeds)


;; -----------------------------------------------------------------------------
;; Variables [cleite:items]
;;
(defcustom cleite:items:window-height 12
  "Height of the feed item list window"
  :type  'integer
  :group 'cleite:items)


(defcustom cleite:items:sort-criteria '((date . ascending))
  "Sort feed items by what criteria"
  :type  '(repeat (choice (const :tag "Read items come first"   (read-flag . read-first  ))
						  (const :tag "Unread items come first" (read-flag . unread-first))
						  (cons  (choice (const :tag "Sort by title" title)
										 (const :tag "Sort by date"  date ))
								 (choice (const :tag "Ascending"  ascending)
										 (const :tag "Descending" descending)))))
  :group 'cleite:items)


(defcustom cleite:items:jump-to-unread t
  "Jump to an unread feed item when we open the feed list"
  :type  'boolean
  :group 'cleite:items)


;; -----------------------------------------------------------------------------
;; Variables (non-customizable)
;;
(defvar cleite:global-map
  (let ((map (make-sparse-keymap)))
	(define-key map "\C-c\C-p" 'cleite:system:change-password)
	(define-key map "\C-c\C-a" 'cleite:system:add-account)
	(define-key map "\C-c\C-d" 'cleite:system:delete-account)
	(define-key map "\C-c\C-u" 'cleite:system:update-account)
	(define-key map "\C-c\C-v" 'cleite:version)
	map)
  "Global keymap for cleite")


(provide 'cleite-vars)